@@ -27,10 +27,12 @@ sub test_setup_area {
     symlink "${Dist}/project_dir",	'test_dir/prefix/bin/project_dir';
     symlink "${Dist}/project_bin",	'test_dir/prefix/bin/project_bin';
     symlink  "project_bin",		'test_dir/prefix/bin/testprog';
+    _projrun("testprog",		'test_dir/prefix/bin/testrun');
     mkdir				'test_dir/prefix/lib',0777;
     symlink "${Dist}/project_dir.mk",	'test_dir/prefix/lib/project_dir.mk';
     mkdir				'test_dir/checkout',0777;
     mkdir				'test_dir/checkout/bin',0777;
+    mkdir				'test_dir/checkout/Project_Root',0777;
     symlink "${Dist}/t/30_project_bin.pl",'test_dir/checkout/bin/testprog';
     symlink 'checkout',			'test_dir/project';
     $ENV{DIRPROJECT_PREFIX} = "${Dist}/test_dir/prefix";
@@ -38,6 +40,17 @@ sub test_setup_area {
     $ENV{DIRPROJECT_PROJECTDIREXE} = "${PERL} $ENV{DIRPROJECT_PREFIX}/bin/project_dir";
 }
 
+sub _projrun {
+    my $torun = shift;
+    my $filename = shift;
+    my $fh = IO::File->new (">$filename") or die "%Error: $! writing $filename,";
+    (my $shebang = $PERL) =~ s/\'//g;
+    print $fh "#!${shebang}\n";
+    print $fh "exec '${Dist}/project_bin','--project_bin-run','$torun',\@ARGV;\n";
+    $fh->close();
+    chmod 0777, $filename;
+}
+
 ######################################################################
 
 sub run_system {
